Contributing to pyfat
=====================

Feel free to contribute improvements to this package via pull request.

The preferred method of development is a test driven approach and following the
`nvie git flow <https://nvie.com/posts/a-successful-git-branching-model/>`_
branching model. Please be so kind to bear these things in mind when
handing in improvements.

Thank you very much!
